#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="hurlenko/filebrowser"
}

do_install_detail() {
  local config=`uci get filebrowser.@filebrowser[0].config_path 2>/dev/null`
  local port=`uci get filebrowser.@filebrowser[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get filebrowser.@filebrowser[0].image_name 2>/dev/null`
  local username=`uci get filebrowser.@filebrowser[0].username 2>/dev/null`
  local password=`uci get filebrowser.@filebrowser[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8160
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=hurlenko/filebrowser

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: '3'

volumes:
  filebrowser_config:
  filebrowser_data:

services:
  filebrowser:
    restart: unless-stopped
    image: hurlenko/filebrowser
    volumes:
      - ./config:/config
      - /opt/docker2/compose:/data
    environment:
      - FB_BASEURL=/filebrowser
    ports:
      - ${port}:8080
    labels:
      plugsy.name: "Filebrowser"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/fa-solid/FolderOpen"
      plugsy.link: "http://${LAN_IP}:${port}"
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install filebrowser"
  echo "      upgrade                Upgrade filebrowser"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart filebrowser"
  echo "      status                 filebrowser status"
  echo "      port                   filebrowser port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f filebrowser
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} filebrowser
  ;;
  "status")
    docker ps --all -f 'name=filebrowser' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=filebrowser' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
